﻿using RGF_BLL;
using RGF_UI;
using System;
using System.Data;
using System.Data.SqlClient;
using System.Drawing;
using System.Windows.Forms;

namespace RGF_Inventory_Bonakdar
{
    public partial class Frm_Backup : Form
    {
        public Frm_Backup()
        {
            InitializeComponent();
            Dgv_Commo.AlternatingRowsDefaultCellStyle.BackColor = Color.FromArgb(216, 232, 237);
        }

        string name, space;

        /// <summary>
        /// بستن پنجره با زدن اسکپ
        /// scape for close
        /// </summary>
        /// <param name="msg"></param>
        /// <param name="keyData"></param>
        /// <returns></returns>
        protected override bool ProcessCmdKey(ref Message msg, Keys keyData)
        {
            if (keyData == Keys.Escape)
            {
                this.Close();
                return true;
            }
            return base.ProcessCmdKey(ref msg, keyData);
        }

        private void Grid_View()
        {
            Dgv_Commo.DataSource = new Usable_Bll().Show_Backup();
        }

        private void Load_Info()
        {
            name = Frm_Login.name;
            space = new Usable_Bll().DB_Space().Rows[0][1].ToString();
        }

        /// <summary>
        /// متود بکاپ
        /// </summary>
        /// <param name="filename"></param>
        private void Backuper(string filename)
        {
            Wait.ShowLoadingScreen(this);
            try
            {
                string command = @"BACKUP DATABASE Bonakdar_DB TO DISK=N'" + filename + "'";
                this.Cursor = Cursors.WaitCursor;
                SqlCommand ocommand = null;
                SqlConnection oconnection = null;
                oconnection = new SqlConnection(Properties.Settings.Default.Connect);
                if (oconnection.State != ConnectionState.Open)
                    oconnection.Open();
                ocommand = new SqlCommand(command, oconnection);
                ocommand.ExecuteNonQuery();
                this.Cursor = Cursors.Default;
            }
            catch
            {
                Error.ShowBox(@"اتصال برنامه به دیتابیس را بررسی نمایید
و یا نسخه را در درایو ویندوز ایجاد نموده اید .", "خطا");
            }
            Wait.CloseLoadingScreen();
            this.Activate();
            Ok.ShowBox("نسخه پشتیبان با موفقیت ایجاد شد .", "نسخه پشتیبان");
        }

        /// <summary>
        /// متود ری اسنور
        /// </summary>
        /// <param name="strFileName"></param>
        private void Restore(string strFileName)
        {
            Wait.ShowLoadingScreen(this);
            try
            {
                if (strFileName != string.Empty)
                {
                    string command = "ALTER DATABASE Bonakdar_DB SET OFFLINE with ROLLBACK IMMEDIATE RESTORE DATABASE Bonakdar_DB FROM DISK = '" + strFileName + "'" + " WITH REPLACE";
                    var oConnection = new SqlConnection(Properties.Settings.Default.Connect);
                    if (oConnection.State != ConnectionState.Open)
                        oConnection.Open();
                    var oCommand = new SqlCommand(command, oConnection);
                    oCommand.ExecuteNonQuery();
                }
            }
            catch
            {
                Error.ShowBox(@"خطا در ایجاد نسخه پشتیبان
اتصال برنامه به دیتابیس را بررسی نمایید .", "خطا");
                Wait.CloseLoadingScreen();
            }
            Wait.CloseLoadingScreen();
            this.Activate();
        }

        /// <summary>
        /// متود درج
        /// </summary>
        private void Insert_Backup()
        {
            try
            {
                new Usable_Bll().Insert_Backup(name, space, Convert.ToDateTime(Dte_Backup.Value));
            }
            catch
            {
                Error.ShowBox("خطا در درج اطلاعات نسخه پشتیبان .", "خطا");
            }
        }

        private void Frm_Backup_Load(object sender, EventArgs e)
        {
            Grid_View();
            Load_Info();
        }

        private void Btn_Backup_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrWhiteSpace(Dte_Backup.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "تاریخ !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Dte_Backup, 5000);
                TT.Show("تاریخ را انتخاب کنید", Dte_Backup);
            }
            else if (Dte_Backup.Text != "")
            {
                SaveFileDialog SFD = new SaveFileDialog();
                string strFileName = string.Empty;
                SFD.OverwritePrompt = true;
                SFD.DefaultExt = "";
                SFD.Filter = @"SQL Backup Files (*.*) |*.*| (*.Bak)|*.Bak";
                SFD.FilterIndex = 1;
                SFD.FileName = " نسخه ایجاد شده توسط ،  " + name;
                SFD.Title = "ایجاد نسخه پشتیبان";
                if (SFD.ShowDialog() == DialogResult.OK)
                {
                    strFileName = SFD.FileName;
                    Backuper(strFileName);
                    Insert_Backup();
                    Dte_Backup.ResetText();
                    Grid_View();
                }
            }
        }

        private void Btn_Restore_Click(object sender, EventArgs e)
        {
            try
            {
                OpenFileDialog OPD = new OpenFileDialog();
                string filename = string.Empty;
                OPD.Filter = @"SQL Backup Files ALL Files (*.*) |*.*| (*.Bak)|*.Bak";
                OPD.FilterIndex = 1;
                OPD.Filter = @"SQL Backup Files (*.*)|";
                OPD.Title = "بارگذاری نسخه پشتیبان";
                if (OPD.ShowDialog() == DialogResult.OK)
                {
                    filename = OPD.FileName;
                    Restore(filename);
                }
            }
            catch
            {
                Error.ShowBox(@"خطا در بارگذاری نسخه پشتیبان
اتصال برنامه به دیتابیس را بررسی نمایید .", "خطا");
            }
        }

        private void Dgv_Commo_CellFormatting(object sender, DataGridViewCellFormattingEventArgs e)
        {
            if (e.ColumnIndex == 3)
            {
                object value = e.Value;
                if (value is DateTime)
                {
                    e.Value = new Information_Bll().GetPersianDate((DateTime)e.Value);
                    e.FormattingApplied = true;
                }
            }
        }
    }
}
