﻿using RGF_BLL;
using RGF_UI;
using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using Stimulsoft.Report.Components;

namespace RGF_Inventory_Bonakdar
{
    public partial class Frm_Document : Form
    {
        private DataTable Add_Order = new DataTable(); // ایجاد دیتاتیبل جهت وارد کردن مقادیر به دیتاگریدویو
        Invoice_Bll Header = new Invoice_Bll();
        int Invoice_Last_Id;

        public Frm_Document()
        {
            InitializeComponent();
            Dgv_Order.AlternatingRowsDefaultCellStyle.BackColor = Color.FromArgb(216, 232, 237);
            initialiseTable(this.Add_Order); // اضافه کردن سفارشات به دیتاگریدویو
            Dgv_Order.DataSource = this.Add_Order;
        }

        Txt_Clean tc = new Txt_Clean();

        /// <summary>
        /// بستن پنجره با زدن اسکپ
        /// scape for close
        /// </summary>
        /// <param name="msg"></param>
        /// <param name="keyData"></param>
        /// <returns></returns>
        protected override bool ProcessCmdKey(ref Message msg, Keys keyData)
        {
            if (keyData == Keys.Escape)
            {
                this.Close();
                return true;
            }
            return base.ProcessCmdKey(ref msg, keyData);
        }

        #region Grid_View
        /// <summary>
        /// ایجاد دیتاتیبل جهت درج سفارشات در دیتاگریدویو
        /// </summary>
        /// <param name="table"></param>
        private void initialiseTable(DataTable table)
        {
            table.Columns.Add(new DataColumn("Doc_Id"));
            table.Columns.Add(new DataColumn("Commodity_Id"));
            table.Columns.Add(new DataColumn("Commodity"));
            table.Columns.Add(new DataColumn("Quantity"));
            table.Columns.Add(new DataColumn("Unit"));
        }
        /// <summary>
        /// بایند کمبوباکس ها و هدر دیتاگریدویو 
        /// </summary>
        private void Bind_Combo()
        {
            Cmb_Warehouse.DataSource = new Warehouse_Bll().Ware_No_Combo();
            Cmb_Warehouse.DisplayMember = "Name";
            Cmb_Warehouse.ValueMember = "Id";
            Cmb_Person.DataSource = new Person_Bll().Person_No_Combo();
            Cmb_Person.DisplayMember = "Name";
            Cmb_Person.ValueMember = "Id";
            Cmb_Commodity.DataSource = new Commodity_Bll().Commo_No_Combo();
            Cmb_Commodity.DisplayMember = "Name";
            Cmb_Commodity.ValueMember = "Id";
            Cmb_Unit.DataSource = new Unit_Bll().Unit_Combo();
            Cmb_Unit.DisplayMember = "Unit";
            Cmb_Warehouse.ResetText();
            Cmb_Person.ResetText();
            Cmb_Commodity.ResetText();
            Cmb_Unit.ResetText();
            Dgv_Order.Columns["Doc_Id"].Visible = false;
            Dgv_Order.Columns["Commodity_Id"].HeaderText = "شماره کالا";
            Dgv_Order.Columns["Commodity_Id"].Width = 120;
            Dgv_Order.Columns["Commodity"].HeaderText = "نام کالا";
            Dgv_Order.Columns["Commodity"].Width = 320;
            Dgv_Order.Columns["Quantity"].HeaderText = "تعداد";
            Dgv_Order.Columns["Quantity"].Width = 100;
            Dgv_Order.Columns["Unit"].HeaderText = "واحد کالا";
            Dgv_Order.Columns["Unit"].Width = 230;
        }
        #endregion

        private void Frm_Document_Load(object sender, EventArgs e)
        {
            Bind_Combo();
            Invoice_Last_Id = new Document_Bll().Max_Id();
            Lbl_Invoice_Id.Text = "شماره آخرین سند ثبت شده : " + Invoice_Last_Id.ToString();
        }

        #region Insert_Doc
        private void Btn_Add_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrWhiteSpace(Cmb_Commodity.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "نام کالا !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Commodity, 5000);
                TT.Show("نام کالا را انتخاب کنید", Cmb_Commodity);
            }
            else if (string.IsNullOrWhiteSpace(Txt_Quantity.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "تعداد !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Txt_Quantity, 5000);
                TT.Show("تعداد کالا را وارد نمایید", Txt_Quantity);
            }
            else if (string.IsNullOrWhiteSpace(Cmb_Unit.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "واحد !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Unit, 5000);
                TT.Show("واحد کالا را انتخاب کنید", Cmb_Unit);
            }
            else if (Cmb_Commodity.Text != "" && Txt_Quantity.Text != "" && Cmb_Unit.Text != "")
            {
                try
                {
                    DataRow rd = Add_Order.NewRow();
                    rd[0] = Invoice_Last_Id + 1;
                    rd[1] = Cmb_Commodity.SelectedValue;
                    rd[2] = Cmb_Commodity.Text;
                    rd[3] = Txt_Quantity.Text;
                    rd[4] = Cmb_Unit.Text;
                    Add_Order.Rows.Add(rd);
                }
                catch
                {
                    Error.ShowBox(@"عدم ثبت سفارش ...
عدم ثبت سفارشات فاکتور .", "خطا !");
                }
                Cmb_Commodity.ResetText();
                Txt_Quantity.Text = "";
                Cmb_Unit.ResetText();
            }
        }

        private void Insert_Document()
        {
            string Document_Id;
            string Commodity_Id;
            string Quantity;
            string Unit;
            Boolean Doc_Type;
            if (Cmb_Type.SelectedItem.Equals("حواله"))
                Doc_Type = false;
            else
                Doc_Type = true;
            try
            {
                Document_Bll.Insert_Document(Convert.ToInt32(Cmb_Warehouse.SelectedValue), Convert.ToInt32(Txt_Invoice.Text), Cmb_Type.Text, Doc_Type, Convert.ToInt32(Cmb_Person.SelectedValue), Convert.ToDateTime(Dte_Invoice.Value), Txt_Desc.Text.Trim());
                for (int i = 0; i <= Dgv_Order.Rows.Count - 2; i++)
                {
                    Document_Id = Dgv_Order.Rows[i].Cells[0].Value.ToString();
                    Commodity_Id = Dgv_Order.Rows[i].Cells[1].Value.ToString();
                    Quantity = Dgv_Order.Rows[i].Cells[3].Value.ToString();
                    Unit = Dgv_Order.Rows[i].Cells[4].Value.ToString();
                    Document_Commo_Bll.Insert_Doc_Commo(Convert.ToInt32(Document_Id), Convert.ToInt32(Commodity_Id), Convert.ToInt32(Quantity), Unit);
                    Document_Id = "";
                    Commodity_Id = "";
                    Quantity = "";
                    Unit = "";
                }
                Ok.ShowBox(" سند " + Cmb_Type.Text + " کالا ثبت شد . ", "ثبت با موفقیت انجام شد !");               
            }
            catch
            {
                Error.ShowBox(@"مشخصات سند ...
اتصال برنامه به دیتابیس را بررسی نمایید .", "سند ذخیره نشد !");
            }
        }

        void Doc_Report()
        {
            DataTable table = new DataTable("Orders_Rows");
            foreach (DataGridViewColumn column in Dgv_Order.Columns)
                table.Columns.Add(column.Name, typeof(string));
            for (int i = 0; i < Dgv_Order.Rows.Count; i++)
            {
                table.Rows.Add();
                for (int j = 0; j < Dgv_Order.Columns.Count; j++)
                {
                    table.Rows[i][j] = Dgv_Order[j, i].Value;
                }
            }
            DataTable textable = new DataTable("Document_Text");
            DataColumn Warehouse = new DataColumn("Warehouse", typeof(string));
            DataColumn Invoice = new DataColumn("Invoice", typeof(string));
            DataColumn Person = new DataColumn("Person", typeof(string));
            DataColumn Type = new DataColumn("Type", typeof(string));
            DataColumn Dat = new DataColumn("Date", typeof(string));
            DataColumn Desc = new DataColumn("Desc", typeof(string));
            textable.Columns.AddRange(new DataColumn[] { Warehouse, Invoice, Person, Type, Dat, Desc });
            DataRow Dr = textable.NewRow();
            Dr[0] = Cmb_Warehouse.Text;
            Dr[1] = Txt_Invoice.Text;
            Dr[2] = Cmb_Person.Text;
            Dr[3] = Cmb_Type.Text;            
            Dr[4] = Dte_Invoice.GetText("yyyy/MM/dd");
            Dr[5] = Txt_Desc.Text;
            textable.Rows.Add(Dr);
            DataSet Ds = new DataSet();
            Ds.Tables.Add(table);
            Stimulsoft.Report.StiReport Report_Sti = new Stimulsoft.Report.StiReport();
            Report_Sti.Load(System.Windows.Forms.Application.StartupPath + @"\Data\Document.mrt");
            Report_Sti.RegData(table);
            Report_Sti.RegData(textable);
            Report_Sti.Dictionary.Variables["Name"].Value = Header.Invoice_Header().Rows[0]["Name"].ToString();
            Image bmp = null;
            System.IO.FileStream stream = null;
            string fileName = (Application.StartupPath + @"\Data\Logo\1.png");
            stream = new System.IO.FileStream(fileName, System.IO.FileMode.Open, System.IO.FileAccess.Read);
            byte[] buf = new byte[stream.Length];
            stream.Read(buf, 0, buf.Length);
            bmp = Image.FromStream(new System.IO.MemoryStream(buf));
            (Report_Sti.GetComponentByName("Logo") as StiImage).Image = bmp;
            Report_Sti.ReportName = "صدور فاکتور";
            Report_Sti.Compile();
            //Report_Sti.Design();                       
            Report_Sti.Show();
        }

        private void Btn_Insert_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrWhiteSpace(Cmb_Warehouse.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "نام انبار !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Warehouse, 5000);
                TT.Show("انبار را انتخاب کنید", Cmb_Warehouse);
            }
            else if (string.IsNullOrWhiteSpace(Cmb_Person.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "طرف حساب !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Person, 5000);
                TT.Show("طرف حساب را انتخاب کنید", Cmb_Person);
            }
            else if (string.IsNullOrWhiteSpace(Txt_Invoice.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "عطف !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Txt_Invoice, 5000);
                TT.Show("شماره عطف را وارد نمایید", Txt_Invoice);
            }
            else if (string.IsNullOrWhiteSpace(Cmb_Type.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "نوع سند !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Type, 5000);
                TT.Show("نوع سند را انتخاب کنید", Cmb_Type);
            }
            else if (string.IsNullOrWhiteSpace(Dte_Invoice.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "تاریخ سند !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Dte_Invoice, 5000);
                TT.Show("تاریخ سند را وارد نمایید", Dte_Invoice);
            }
            else if (Cmb_Warehouse.Text != "" && Cmb_Person.Text != "" && Dte_Invoice.Value != null)
            {
                if (Dgv_Order.Rows.Count > 1)
                {
                    Insert_Document();
                    Doc_Report();
                    tc.ClearTxt(this);
                    Cmb_Warehouse.ResetText();
                    Cmb_Person.ResetText();
                    Cmb_Type.ResetText();
                    Dte_Invoice.ResetText();
                    Add_Order.Clear();
                    Frm_Document_Load(null, null);
                }
                else
                {
                    Error.ShowBox(@"کالاهای سند ...
کالاهای سند را وارد نمایید .", "سند ذخیره نشد !");
                }
            }
        }
        #endregion

    }
}