﻿using RGF_BLL;
using RGF_UI;
using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.IO;
using Stimulsoft.Report.Components;

namespace RGF_Inventory_Bonakdar
{
    public partial class Frm_Invoice : Form
    {
        private DataTable Add_Order = new DataTable(); // ایجاد دیتاتیبل جهت وارد کردن مقادیر به دیتاگریدویو
        Invoice_Bll Header = new Invoice_Bll();
        int Invoice_Last_Id;
        Txt_Clean tc = new Txt_Clean();

        public Frm_Invoice()
        {
            InitializeComponent();
            Dgv_Order.AlternatingRowsDefaultCellStyle.BackColor = Color.FromArgb(216, 232, 237);
            initialiseTable(this.Add_Order); // اضافه کردن سفارشات به دیتاگریدویو
            Dgv_Order.DataSource = this.Add_Order;
        }

        /// <summary>
        /// بستن پنجره با زدن اسکپ
        /// scape for close
        /// </summary>
        /// <param name="msg"></param>
        /// <param name="keyData"></param>
        /// <returns></returns>
        protected override bool ProcessCmdKey(ref Message msg, Keys keyData)
        {
            if (keyData == Keys.Escape)
            {
                this.Close();
                return true;
            }
            return base.ProcessCmdKey(ref msg, keyData);
        }

        /// <summary>
        /// چک کردن فعال بودن برنامه
        /// </summary>
        private void Expire() // فعالسازی برنامه
        {
            if (Properties.Settings.Default.Reg_Check == true)
            {
                new Serial().Trial_Expired();
                Application.ExitThread();
            }
        }

        #region Grid_View
        /// <summary>
        /// ایجاد دیتاتیبل جهت درج سفارشات در دیتاگریدویو
        /// </summary>
        /// <param name="table"></param>
        private void initialiseTable(DataTable table)
        {
            table.Columns.Add(new DataColumn("Invoice_Id"));
            table.Columns.Add(new DataColumn("Commodity_Id"));
            table.Columns.Add(new DataColumn("Commodity"));
            table.Columns.Add(new DataColumn("Quantity"));
            table.Columns.Add(new DataColumn("Price"));
            table.Columns.Add(new DataColumn("Sum"));
        }

        /// <summary>
        /// بایند کمبوباکس ها و هدر دیتاگریدویو 
        /// </summary>
        private void Bind_Combo()
        {
            Cmb_Person.DataSource = new Person_Bll().Person_No_Combo();
            Cmb_Person.DisplayMember = "Name";
            Cmb_Person.ValueMember = "Id";
            Cmb_Commodity.DataSource = new Commodity_Bll().Commo_No_Combo();
            Cmb_Commodity.DisplayMember = "Name";
            Cmb_Commodity.ValueMember = "Id";
            Cmb_Person.ResetText();
            Cmb_Commodity.ResetText();
            Dgv_Order.Columns["Invoice_Id"].HeaderText = "شماره فاکتور";
            Dgv_Order.Columns["Invoice_Id"].Visible = false;
            Dgv_Order.Columns["Commodity_Id"].HeaderText = "شماره کالا";
            Dgv_Order.Columns["Commodity_Id"].Width = 120;
            Dgv_Order.Columns["Commodity"].HeaderText = "نام کالا";
            Dgv_Order.Columns["Commodity"].Width = 320;
            Dgv_Order.Columns["Quantity"].HeaderText = "تعداد";
            Dgv_Order.Columns["Quantity"].Width = 100;
            Dgv_Order.Columns["Price"].HeaderText = "قیمت واحد";
            Dgv_Order.Columns["Price"].Width = 230;
            Dgv_Order.Columns["Sum"].HeaderText = "جمع سطر به ریال";
            Dgv_Order.Columns["Sum"].Width = 150;           
        }

        /// <summary>
        /// شماره آخرین فاکتور ثبت شده
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Frm_Invoice_Load(object sender, EventArgs e)
        {
            Expire();
            Bind_Combo();
            Invoice_Last_Id = new Invoice_Bll().Max_Id();
            Lbl_Invoice_Id.Text = "شماره آخرین فاکتور ثبت شده : " + Invoice_Last_Id.ToString();
        }

        /// <summary>
        /// کلید اضافه کردن سفارش در گریدویو
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Btn_Add_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrWhiteSpace(Cmb_Commodity.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "نام کالا !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Commodity, 5000);
                TT.Show("نام کالا را انتخاب کنید", Cmb_Commodity);
            }
            else if (string.IsNullOrWhiteSpace(Txt_Quantity.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "تعداد !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Txt_Quantity, 5000);
                TT.Show("تعداد کالا را وارد نمایید", Txt_Quantity);
            }
            else if (string.IsNullOrWhiteSpace(Txt_Price.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "قیمت !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Txt_Price, 5000);
                TT.Show("قیمت هر واحد کالا را وارد نمایید", Txt_Price);
            }
            else if (Cmb_Commodity.Text != "" && Txt_Quantity.Text != "" && Txt_Price.Text != "")
            {
                try
                {
                    DataRow rd = Add_Order.NewRow();
                    rd[0] = Invoice_Last_Id + 1;
                    rd[1] = Cmb_Commodity.SelectedValue;
                    rd[2] = Cmb_Commodity.Text;
                    rd[3] = Txt_Quantity.Text;
                    rd[4] = Txt_Price.Text;
                    rd[5] = Convert.ToInt32(Txt_Quantity.Text) * Convert.ToInt32(Txt_Price.Text);
                    Add_Order.Rows.Add(rd);
                }
                catch
                {
                    Error.ShowBox(@"عدم ثبت سفارش ...
عدم ثبت سفارشات فاکتور .", "خطا !");
                }
                Cmb_Commodity.ResetText();
                Txt_Quantity.Text = "";
                Txt_Price.Text = "";
            }            
        }
        #endregion

        #region Insert & Print
        /// <summary>
        /// کلید درج اطلاعات و در ادامه سفارشات فاکتور
        /// </summary>
        private void Insert_Invoice()
        {
            Boolean Invoice_Type;
            string Invoice_Id;
            string Commodity_Id;
            string Quantity;
            string Unit_Price;
            if (Cmb_Type.SelectedItem.Equals("خرید"))
                Invoice_Type = false;
            else
                Invoice_Type = true;
            try
            {
                Invoice_Bll.Insert_Invoice(Convert.ToInt32(Cmb_Person.SelectedValue), Cmb_Type.Text.Trim(), Convert.ToDateTime(Dte_Invoice.Value), Invoice_Type);
                for (int i = 0; i <= Dgv_Order.Rows.Count - 2; i++)
                {
                    Invoice_Id = Dgv_Order.Rows[i].Cells[0].Value.ToString();
                    Commodity_Id = Dgv_Order.Rows[i].Cells[1].Value.ToString();
                    Quantity = Dgv_Order.Rows[i].Cells[3].Value.ToString();
                    Unit_Price = Dgv_Order.Rows[i].Cells[4].Value.ToString();
                    Order_Bll.Insert_Order(Convert.ToInt32(Invoice_Id), Convert.ToInt32(Commodity_Id), Convert.ToInt32(Quantity), Convert.ToInt32(Unit_Price));
                    Invoice_Id = "";
                    Commodity_Id = "";
                    Quantity = "";
                    Unit_Price = "";
                }
                Ok.ShowBox(" فاکتور به نام " + Cmb_Person.Text + @"
ثبت شد .", "ثبت با موفقیت انجام شد !");
                tc.ClearTxt(this);
            }
            catch
            {
                Error.ShowBox(@"مشخصات فاکتور ...
اتصال برنامه به دیتابیس را بررسی نمایید .", "فاکتور ذخیره نشد !");
            }
        }        

        /// <summary>
        /// ارسال داده های تکست باکس ها و گریدویو به استیمول ریپورت
        /// </summary>
        void Invoice_Report()
        {
            DataTable table = new DataTable("Orders_Rows");
            foreach (DataGridViewColumn column in Dgv_Order.Columns)
                table.Columns.Add(column.Name, typeof(string));
            for (int i = 0; i < Dgv_Order.Rows.Count; i++)
            {
                table.Rows.Add();
                for (int j = 0; j < Dgv_Order.Columns.Count; j++)
                {
                    table.Rows[i][j] = Dgv_Order[j, i].Value;
                }
            }
            DataTable textable = new DataTable("Invoice_Text");
            DataColumn Customer = new DataColumn("Customer", typeof(string));
            DataColumn Type = new DataColumn("Type", typeof(string));
            DataColumn Dat = new DataColumn("Date", typeof(string));            
            textable.Columns.AddRange(new DataColumn[] { Customer, Type, Dat });
            DataRow Dr = textable.NewRow();
            Dr[0] = Cmb_Person.Text;
            Dr[1] = Cmb_Type.Text;
            Dr[2] = Dte_Invoice.GetText("yyyy/MM/dd");
            textable.Rows.Add(Dr);
            DataSet Ds = new DataSet();
            Ds.Tables.Add(table);
            Stimulsoft.Report.StiReport Report_Sti = new Stimulsoft.Report.StiReport();
            Report_Sti.Load(System.Windows.Forms.Application.StartupPath + @"\Data\Invoice.mrt");
            Report_Sti.RegData(table);
            Report_Sti.RegData(textable);
            Report_Sti.Dictionary.Variables["Name"].Value = Header.Invoice_Header().Rows[0]["Name"].ToString();
            Report_Sti.Dictionary.Variables["Phone_No"].Value = Header.Invoice_Header().Rows[0]["Phone_no"].ToString();
            Report_Sti.Dictionary.Variables["City"].Value = Header.Invoice_Header().Rows[0]["City"].ToString();
            Report_Sti.Dictionary.Variables["Address"].Value = Header.Invoice_Header().Rows[0]["Address"].ToString();
            Image bmp = null;
            System.IO.FileStream stream = null;
            string fileName = (Application.StartupPath + @"\Data\Logo\1.png");
            stream = new System.IO.FileStream(fileName, System.IO.FileMode.Open, System.IO.FileAccess.Read);
            byte[] buf = new byte[stream.Length];
            stream.Read(buf, 0, buf.Length);
            bmp = Image.FromStream(new System.IO.MemoryStream(buf));
            (Report_Sti.GetComponentByName("Logo") as StiImage).Image = bmp;
            Report_Sti.ReportName = "صدور فاکتور";
            Report_Sti.Compile();
           // Report_Sti.Design();                       
            Report_Sti.Show();
        }

        /// <summary>
        /// کلید ثبت فاکتور در بانک
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Btn_Insert_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrWhiteSpace(Cmb_Person.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "طرف حساب !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Person, 5000);
                TT.Show("طرف حساب را انتخاب کنید", Cmb_Person);
            }
            else if (string.IsNullOrWhiteSpace(Cmb_Type.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "نوع فاکتور !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Cmb_Type, 5000);
                TT.Show("نوع فاکتور را انتخاب کنید", Cmb_Type);
            }
            else if (string.IsNullOrWhiteSpace(Dte_Invoice.Text))
            {
                ToolTip TT = new ToolTip();
                TT.Active = true;
                TT.ToolTipTitle = "تاریخ فاکتور !";
                TT.ToolTipIcon = ToolTipIcon.Warning;
                TT.Show(string.Empty, Dte_Invoice, 5000);
                TT.Show("تاریخ فاکتور را وارد نمایید", Dte_Invoice);
            }
            else if (Cmb_Person.Text != "" && Cmb_Type.Text != "" && Dte_Invoice.Value != null)
            {
                if (Dgv_Order.Rows.Count > 1)
                {
                    Insert_Invoice();
                    Invoice_Report();
                    tc.ClearTxt(this);
                    Cmb_Person.ResetText();
                    Cmb_Type.ResetText();
                    Dte_Invoice.ResetText();
                    Add_Order.Clear();
                    Frm_Invoice_Load(null, null);
                }
                else
                {
                    Error.ShowBox(@"سفارشات فاکتور ...
سفارشات فاکتور را وارد نمایید .", "فاکتور ذخیره نشد !");
                }     
            }
        }
        #endregion
    }
}
